#include "../usbaudio.inc"
#include "../../alsa-kernel/usb/misc/ua101.c"
EXPORT_NO_SYMBOLS;
